pub struct CompositorSurface {
pub descriptor: ExternalSurfaceDescriptor,
prohibited_rect: PictureRect,
pub is_opaque: bool,
}Expand description
Wrapper struct around an external surface descriptor with a little more information that the picture caching code needs.
Fields
descriptor: ExternalSurfaceDescriptorprohibited_rect: PictureRectis_opaque: boolAuto Trait Implementations
impl Freeze for CompositorSurface
impl RefUnwindSafe for CompositorSurface
impl Send for CompositorSurface
impl Sync for CompositorSurface
impl Unpin for CompositorSurface
impl UnsafeUnpin for CompositorSurface
impl UnwindSafe for CompositorSurface