pub struct PictureScratch {
pub primary_render_task_id: Option<RenderTaskId>,
pub secondary_render_task_id: Option<RenderTaskId>,
pub extra_gpu_data: SmallVec<[GpuBufferAddress; 1]>,
}Expand description
Per-frame scratch data for a Picture primitive. Pushed in take_context
and read by both prepare and batch through the scratch_handle carried
on PrimitiveKind::Picture.
Fields
primary_render_task_id: Option<RenderTaskId>All render tasks have 0-2 input tasks.
secondary_render_task_id: Option<RenderTaskId>If a mix-blend-mode, contains the render task for the readback of the framebuffer that we use to sample from in the mix-blend-mode shader. For drop-shadow filter, this will store the original picture task which would be rendered on screen after blur pass. This is also used by SVGFEBlend, SVGFEComposite and SVGFEDisplacementMap filters.
extra_gpu_data: SmallVec<[GpuBufferAddress; 1]>Optional cache handles for storing extra data in the GPU cache, depending on the type of picture.
Implementations