pub struct TileCacheParams {
pub debug_flags: DebugFlags,
pub slice: usize,
pub slice_flags: SliceFlags,
pub spatial_node_index: SpatialNodeIndex,
pub visibility_node_index: SpatialNodeIndex,
pub background_color: Option<ColorF>,
pub shared_clip_node_id: ClipNodeId,
pub shared_clip_leaf_id: Option<ClipLeafId>,
pub virtual_surface_size: i32,
pub image_surface_count: usize,
pub yuv_image_surface_count: usize,
}Expand description
Information that is required to reuse or create a new tile cache. Created during scene building and passed to the render backend / frame builder.
Fields
debug_flags: DebugFlagsslice: usizeslice_flags: SliceFlagsspatial_node_index: SpatialNodeIndexvisibility_node_index: SpatialNodeIndexbackground_color: Option<ColorF>virtual_surface_size: i32image_surface_count: usizeyuv_image_surface_count: usizeAuto Trait Implementations
impl Freeze for TileCacheParams
impl RefUnwindSafe for TileCacheParams
impl Send for TileCacheParams
impl Sync for TileCacheParams
impl Unpin for TileCacheParams
impl UnsafeUnpin for TileCacheParams
impl UnwindSafe for TileCacheParams